@@ -29,7 +29,7 @@ my $tags = {
             '</i>'   => '_',
             '<tt>'   => '@',
             '</tt>'  => '@',
-            '<pre>'  => '<pre>\n',
+            '<pre>'  => "<pre>\n",
             '</pre>' => "\n</pre>\n\n",
 
             '<h1>'   => 'h1. ',
